@@ -21,7 +21,6 @@
 #define _GNU_SOURCE 1
 #define HAVE_ALLOCA_H 1
 #define HAVE_ARPA_INET_H 1
-/* #undef HAVE_ASM_MSR_H */
 #define HAVE_ASM_TERMBITS_H 1
 #define HAVE_CRYPT_H 1
 #define HAVE_CURSES_H 1
@@ -186,9 +185,6 @@
 #define HAVE_POSIX_FALLOCATE 1
 #define HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE 1
 #define HAVE_PREAD 1
-/* #undef HAVE_PAUSE_INSTRUCTION */
-/* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
-/* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
 #define HAVE_PTHREAD_ATTR_GETGUARDSIZE 1
@@ -384,7 +380,6 @@
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
-#define HAVE_GCC_ATOMIC_BUILTINS 1
 #define HAVE_GCC_C11_ATOMICS 1
 /* #undef HAVE_SOLARIS_ATOMIC */
 #define HAVE_DECL_SHM_HUGETLB 1
@@ -539,16 +534,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 4
-#define MYSQL_VERSION_PATCH 6
+#define MYSQL_VERSION_PATCH 8
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.4.6"
+#define PACKAGE_STRING "MySQL Server 10.4.8"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.4.6"
-#define VERSION "10.4.6"
+#define PACKAGE_VERSION "10.4.8"
+#define VERSION "10.4.8"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
