@@ -11,21 +11,22 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"10.3.12-MariaDB"
-#define MYSQL_BASE_VERSION		"mysqld-10.3"
-#define MARIADB_BASE_VERSION		"mariadb-10.3"
+#define MYSQL_SERVER_VERSION		"10.4.8-MariaDB"
+#define MYSQL_BASE_VERSION		"mysqld-10.4"
+#define MARIADB_BASE_VERSION		"mariadb-10.4"
+#define MARIADBD_BASE_VERSION		"mariadbd-10.4"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		100312
+#define MYSQL_VERSION_ID		100408
 #define MYSQL_PORT			3306
 #define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/run/mysqld/mysqld.sock"
 #define MYSQL_CONFIG_NAME		"my"
-#define MYSQL_COMPILATION_COMMENT	"Source distribution"
+#define MYSQL_COMPILATION_COMMENT	"Arch Linux"
 #define SERVER_MATURITY_LEVEL           MariaDB_PLUGIN_MATURITY_STABLE
 
 #ifdef WITH_WSREP
-#define WSREP_PATCH_VERSION             "wsrep_25.23"
+#define WSREP_PATCH_VERSION             "wsrep_26.22"
 #endif
 
 /* mysqld compile time options */
